=========
Changelog
=========

-------------------
v1.2.0 (2023-08-08)
-------------------

* Optimize bit shift
* Add pre-defined char sets
  * Base16 (RFC6468). Note: Same as HexUpper
  * Crockford32
  * WordSafe32 (Another avoid words strategy)


-------------------
v1.1.0 (2022-08-04)
-------------------

* Fixed bit shift selection error
* Reordered Puid constructor arguments
* Altered predefined characters order to match other PUID implementations
* Added cross-repo data testing
* Added optional histogram tests
* Update README
* Create test helpers


-------------------
v1.0.0 (2022-07-29)
-------------------

Initial Release
